@@ -3,7 +3,7 @@ from collections import defaultdict
 
 
 class Context:
-    __slots__ = ('_storage', '_loop')
+    __slots__ = ("_storage", "_loop")
 
     _EVENT_OBJECTS = dict()
 
@@ -33,9 +33,9 @@ def get_context(loop: asyncio.AbstractEventLoop = None) -> Context:
     loop = loop or asyncio.get_event_loop()
 
     if loop.is_closed():
-        raise RuntimeError('event loop is closed')
+        raise RuntimeError("event loop is closed")
 
     return Context._EVENT_OBJECTS[loop]
 
 
-__all__ = ('get_context', 'Context')
+__all__ = ("get_context", "Context")
