@@ -1,5 +1,5 @@
-import tracemalloc
 import logging
+import tracemalloc
 from enum import Enum
 
 from ..periodic import PeriodicCallback
@@ -11,9 +11,9 @@ log = logging.getLogger(__name__)
 
 
 class GroupBy(Enum):
-    lineno = 'lineno'
-    filename = 'filename'
-    traceback = 'traceback'
+    lineno = "lineno"
+    filename = "filename"
+    traceback = "traceback"
 
 
 class MemoryTracer(Service):
@@ -47,19 +47,21 @@ class MemoryTracer(Service):
         self._tracer.start(self.interval)
 
     @staticmethod
-    def humanize(num, suffix='B'):
-        for unit in ('', 'Ki', 'Mi', 'Gi', 'Ti', 'Pi', 'Ei', 'Zi'):
+    def humanize(num, suffix="B"):
+        for unit in ("", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi"):
             if abs(num) < 1024.0:
                 return "%3.1f%s%s" % (num, unit, suffix)
             num /= 1024.0
-        return "%.1f%s%s" % (num, 'Yi', suffix)
+        return "%.1f%s%s" % (num, "Yi", suffix)
 
     @staticmethod
     def take_snapshot() -> tracemalloc.Snapshot:
         return tracemalloc.take_snapshot()
 
-    def compare_snapshot(self, snapshot_from: tracemalloc.Snapshot,
-                         snapshot_to: tracemalloc.Snapshot):
+    def compare_snapshot(
+        self, snapshot_from: tracemalloc.Snapshot,
+        snapshot_to: tracemalloc.Snapshot,
+    ):
         return snapshot_to.compare_to(snapshot_from, self.group_by.value)
 
     def log_diff(self, diff):
@@ -68,7 +70,7 @@ class MemoryTracer(Service):
             "count_diff": "Obj.Diff",
             "size": "Memory",
             "size_diff": "Mem.Diff",
-            "traceback": "Traceback"
+            "traceback": "Traceback",
         }
         for stat in diff[:self.top_results]:
             results += self.STAT_FORMAT % {
@@ -76,7 +78,7 @@ class MemoryTracer(Service):
                 "count_diff": stat.count_diff,
                 "size": self.humanize(stat.size),
                 "size_diff": self.humanize(stat.size_diff),
-                "traceback": stat.traceback
+                "traceback": stat.traceback,
             }
 
         self.logger("Top memory usage:\n%s", results)
@@ -85,7 +87,7 @@ class MemoryTracer(Service):
     def show_stats(self):
         differences = self.compare_snapshot(
             self._snapshot_on_start,
-            self.take_snapshot()
+            self.take_snapshot(),
         )
 
         return self.log_diff(differences)
