@@ -3,7 +3,7 @@ import inspect
 
 class Signal:
 
-    __slots__ = ('_receivers', '_is_frozen')
+    __slots__ = ("_receivers", "_is_frozen")
 
     def __init__(self):
         self._receivers = set()
@@ -16,7 +16,7 @@ class Signal:
             )
 
         if not inspect.iscoroutinefunction(receiver):
-            raise RuntimeError('%r is not a coroutine function', receiver)
+            raise RuntimeError("%r is not a coroutine function", receiver)
 
         self._receivers.add(receiver)
 
